darkhistory.physics.elec_heating_engloss_rate — DarkHistory documentation

# darkhistory.physics.elec_heating_engloss_rate

`darkhistory.physics.` `elec_heating_engloss_rate`(eng, xe, rs)

  Electron energy loss rate of electrons due to Coulomb heating in eV s-1.

  Parameters: | eng : ndarray Abscissa of electron kinetic energy. xe : float The free electron fraction. rs : float The redshift.
  Returns: | ndarray The energy loss rate due to heating (positive).

  Notes

  See 0910.4410 for the expression. The units have e^2/r being in units of energy, so to convert to SI, we insert 1/(4*pi*eps_0)^2.

#### Previous topic

darkhistory.physics.coll_ion_xsec

#### Next topic

darkhistory.utilities

### This Page

Show Source